# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/matcher/v3/struct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import value_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/matcher/v3/struct.proto',
  package='envoy.type.matcher.v3',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.type.matcher.v3B\013StructProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/type/matcher/v3/struct.proto\x12\x15\x65nvoy.type.matcher.v3\x1a!envoy/type/matcher/v3/value.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xac\x02\n\rStructMatcher\x12H\n\x04path\x18\x02 \x03(\x0b\x32\x30.envoy.type.matcher.v3.StructMatcher.PathSegmentB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12<\n\x05value\x18\x03 \x01(\x0b\x32#.envoy.type.matcher.v3.ValueMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1aj\n\x0bPathSegment\x12\x16\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00:3\x9a\xc5\x88\x1e.\n,envoy.type.matcher.StructMatcher.PathSegmentB\x0e\n\x07segment\x12\x03\xf8\x42\x01:\'\x9a\xc5\x88\x1e\"\n envoy.type.matcher.StructMatcherB<\n#io.envoyproxy.envoy.type.matcher.v3B\x0bStructProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STRUCTMATCHER_PATHSEGMENT = _descriptor.Descriptor(
  name='PathSegment',
  full_name='envoy.type.matcher.v3.StructMatcher.PathSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.type.matcher.v3.StructMatcher.PathSegment.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.type.matcher.StructMatcher.PathSegment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='segment', full_name='envoy.type.matcher.v3.StructMatcher.PathSegment.segment',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=341,
  serialized_end=447,
)

_STRUCTMATCHER = _descriptor.Descriptor(
  name='StructMatcher',
  full_name='envoy.type.matcher.v3.StructMatcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.type.matcher.v3.StructMatcher.path', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.type.matcher.v3.StructMatcher.value', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STRUCTMATCHER_PATHSEGMENT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.type.matcher.StructMatcher',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=488,
)

_STRUCTMATCHER_PATHSEGMENT.containing_type = _STRUCTMATCHER
_STRUCTMATCHER_PATHSEGMENT.oneofs_by_name['segment'].fields.append(
  _STRUCTMATCHER_PATHSEGMENT.fields_by_name['key'])
_STRUCTMATCHER_PATHSEGMENT.fields_by_name['key'].containing_oneof = _STRUCTMATCHER_PATHSEGMENT.oneofs_by_name['segment']
_STRUCTMATCHER.fields_by_name['path'].message_type = _STRUCTMATCHER_PATHSEGMENT
_STRUCTMATCHER.fields_by_name['value'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_value__pb2._VALUEMATCHER
DESCRIPTOR.message_types_by_name['StructMatcher'] = _STRUCTMATCHER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StructMatcher = _reflection.GeneratedProtocolMessageType('StructMatcher', (_message.Message,), {

  'PathSegment' : _reflection.GeneratedProtocolMessageType('PathSegment', (_message.Message,), {
    'DESCRIPTOR' : _STRUCTMATCHER_PATHSEGMENT,
    '__module__' : 'envoy.type.matcher.v3.struct_pb2'
    # @@protoc_insertion_point(class_scope:envoy.type.matcher.v3.StructMatcher.PathSegment)
    })
  ,
  'DESCRIPTOR' : _STRUCTMATCHER,
  '__module__' : 'envoy.type.matcher.v3.struct_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.matcher.v3.StructMatcher)
  })
_sym_db.RegisterMessage(StructMatcher)
_sym_db.RegisterMessage(StructMatcher.PathSegment)


DESCRIPTOR._options = None
_STRUCTMATCHER_PATHSEGMENT.oneofs_by_name['segment']._options = None
_STRUCTMATCHER_PATHSEGMENT.fields_by_name['key']._options = None
_STRUCTMATCHER_PATHSEGMENT._options = None
_STRUCTMATCHER.fields_by_name['path']._options = None
_STRUCTMATCHER.fields_by_name['value']._options = None
_STRUCTMATCHER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/rtds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v2/rtds.proto',
  package='envoy.service.discovery.v2',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\001\210\001\001\362\230\376\217\005\032\022\030envoy.service.runtime.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%envoy/service/discovery/v2/rtds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x0b\n\tRtdsDummy\"H\n\x07Runtime\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12&\n\x05layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xf7\x02\n\x17RuntimeDiscoveryService\x12V\n\rStreamRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12_\n\x0c\x44\x65ltaRuntime\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12w\n\x0c\x46\x65tchRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"&\x82\xd3\xe4\x93\x02\x17\"\x15/v2/discovery:runtime\x82\xd3\xe4\x93\x02\x03:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.service.discovery.v2.RuntimeBb\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.service.runtime.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_RTDSDUMMY = _descriptor.Descriptor(
  name='RtdsDummy',
  full_name='envoy.service.discovery.v2.RtdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=292,
)


_RUNTIME = _descriptor.Descriptor(
  name='Runtime',
  full_name='envoy.service.discovery.v2.Runtime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.discovery.v2.Runtime.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer', full_name='envoy.service.discovery.v2.Runtime.layer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=366,
)

_RUNTIME.fields_by_name['layer'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['RtdsDummy'] = _RTDSDUMMY
DESCRIPTOR.message_types_by_name['Runtime'] = _RUNTIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RtdsDummy = _reflection.GeneratedProtocolMessageType('RtdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _RTDSDUMMY,
  '__module__' : 'envoy.service.discovery.v2.rtds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.RtdsDummy)
  })
_sym_db.RegisterMessage(RtdsDummy)

Runtime = _reflection.GeneratedProtocolMessageType('Runtime', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIME,
  '__module__' : 'envoy.service.discovery.v2.rtds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v2.Runtime)
  })
_sym_db.RegisterMessage(Runtime)


DESCRIPTOR._options = None
_RUNTIME.fields_by_name['name']._options = None

_RUNTIMEDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='RuntimeDiscoveryService',
  full_name='envoy.service.discovery.v2.RuntimeDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007$\n\"envoy.service.discovery.v2.Runtime',
  create_key=_descriptor._internal_create_key,
  serialized_start=369,
  serialized_end=744,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamRuntime',
    full_name='envoy.service.discovery.v2.RuntimeDiscoveryService.StreamRuntime',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaRuntime',
    full_name='envoy.service.discovery.v2.RuntimeDiscoveryService.DeltaRuntime',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchRuntime',
    full_name='envoy.service.discovery.v2.RuntimeDiscoveryService.FetchRuntime',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\025/v2/discovery:runtime\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNTIMEDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['RuntimeDiscoveryService'] = _RUNTIMEDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/endpoint_components.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/endpoint/endpoint_components.proto',
  package='envoy.api.v2.endpoint',
  syntax='proto3',
  serialized_options=b'\n#io.envoyproxy.envoy.api.v2.endpointB\027EndpointComponentsProtoP\001\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/envoy/api/v2/endpoint/endpoint_components.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\x08\x45ndpoint\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12N\n\x13health_check_config\x18\x02 \x01(\x0b\x32\x31.envoy.api.v2.endpoint.Endpoint.HealthCheckConfig\x12\x10\n\x08hostname\x18\x03 \x01(\t\x1a\x44\n\x11HealthCheckConfig\x12\x1d\n\nport_value\x18\x01 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03\x12\x10\n\x08hostname\x18\x02 \x01(\t\"\x9a\x02\n\nLbEndpoint\x12\x33\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.EndpointH\x00\x12\x17\n\rendpoint_name\x18\x05 \x01(\tH\x00\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\x12-\n\x08metadata\x18\x03 \x01(\x0b\x32\x1b.envoy.api.v2.core.Metadata\x12\x44\n\x15load_balancing_weight\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x42\x11\n\x0fhost_identifier\"\x90\x02\n\x13LocalityLbEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x37\n\x0clb_endpoints\x18\x02 \x03(\x0b\x32!.envoy.api.v2.endpoint.LbEndpoint\x12\x44\n\x15load_balancing_weight\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x1a\n\x08priority\x18\x05 \x01(\rB\x08\xfa\x42\x05*\x03\x18\x80\x01\x12/\n\tproximity\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueBh\n#io.envoyproxy.envoy.api.v2.endpointB\x17\x45ndpointComponentsProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ENDPOINT_HEALTHCHECKCONFIG = _descriptor.Descriptor(
  name='HealthCheckConfig',
  full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_value', full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig.port_value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.api.v2.endpoint.Endpoint.HealthCheckConfig.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=519,
)

_ENDPOINT = _descriptor.Descriptor(
  name='Endpoint',
  full_name='envoy.api.v2.endpoint.Endpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.api.v2.endpoint.Endpoint.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_check_config', full_name='envoy.api.v2.endpoint.Endpoint.health_check_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='envoy.api.v2.endpoint.Endpoint.hostname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ENDPOINT_HEALTHCHECKCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=519,
)


_LBENDPOINT = _descriptor.Descriptor(
  name='LbEndpoint',
  full_name='envoy.api.v2.endpoint.LbEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='envoy.api.v2.endpoint.LbEndpoint.endpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_name', full_name='envoy.api.v2.endpoint.LbEndpoint.endpoint_name', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health_status', full_name='envoy.api.v2.endpoint.LbEndpoint.health_status', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.api.v2.endpoint.LbEndpoint.metadata', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_weight', full_name='envoy.api.v2.endpoint.LbEndpoint.load_balancing_weight', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='host_identifier', full_name='envoy.api.v2.endpoint.LbEndpoint.host_identifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=522,
  serialized_end=804,
)


_LOCALITYLBENDPOINTS = _descriptor.Descriptor(
  name='LocalityLbEndpoints',
  full_name='envoy.api.v2.endpoint.LocalityLbEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locality', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.locality', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lb_endpoints', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.lb_endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_balancing_weight', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.load_balancing_weight', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.priority', index=3,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005*\003\030\200\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proximity', full_name='envoy.api.v2.endpoint.LocalityLbEndpoints.proximity', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1079,
)

_ENDPOINT_HEALTHCHECKCONFIG.containing_type = _ENDPOINT
_ENDPOINT.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_ENDPOINT.fields_by_name['health_check_config'].message_type = _ENDPOINT_HEALTHCHECKCONFIG
_LBENDPOINT.fields_by_name['endpoint'].message_type = _ENDPOINT
_LBENDPOINT.fields_by_name['health_status'].enum_type = envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2._HEALTHSTATUS
_LBENDPOINT.fields_by_name['metadata'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._METADATA
_LBENDPOINT.fields_by_name['load_balancing_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LBENDPOINT.oneofs_by_name['host_identifier'].fields.append(
  _LBENDPOINT.fields_by_name['endpoint'])
_LBENDPOINT.fields_by_name['endpoint'].containing_oneof = _LBENDPOINT.oneofs_by_name['host_identifier']
_LBENDPOINT.oneofs_by_name['host_identifier'].fields.append(
  _LBENDPOINT.fields_by_name['endpoint_name'])
_LBENDPOINT.fields_by_name['endpoint_name'].containing_oneof = _LBENDPOINT.oneofs_by_name['host_identifier']
_LOCALITYLBENDPOINTS.fields_by_name['locality'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._LOCALITY
_LOCALITYLBENDPOINTS.fields_by_name['lb_endpoints'].message_type = _LBENDPOINT
_LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_LOCALITYLBENDPOINTS.fields_by_name['proximity'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
DESCRIPTOR.message_types_by_name['Endpoint'] = _ENDPOINT
DESCRIPTOR.message_types_by_name['LbEndpoint'] = _LBENDPOINT
DESCRIPTOR.message_types_by_name['LocalityLbEndpoints'] = _LOCALITYLBENDPOINTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Endpoint = _reflection.GeneratedProtocolMessageType('Endpoint', (_message.Message,), {

  'HealthCheckConfig' : _reflection.GeneratedProtocolMessageType('HealthCheckConfig', (_message.Message,), {
    'DESCRIPTOR' : _ENDPOINT_HEALTHCHECKCONFIG,
    '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
    # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.Endpoint.HealthCheckConfig)
    })
  ,
  'DESCRIPTOR' : _ENDPOINT,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.Endpoint)
  })
_sym_db.RegisterMessage(Endpoint)
_sym_db.RegisterMessage(Endpoint.HealthCheckConfig)

LbEndpoint = _reflection.GeneratedProtocolMessageType('LbEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _LBENDPOINT,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.LbEndpoint)
  })
_sym_db.RegisterMessage(LbEndpoint)

LocalityLbEndpoints = _reflection.GeneratedProtocolMessageType('LocalityLbEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _LOCALITYLBENDPOINTS,
  '__module__' : 'envoy.api.v2.endpoint.endpoint_components_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.endpoint.LocalityLbEndpoints)
  })
_sym_db.RegisterMessage(LocalityLbEndpoints)


DESCRIPTOR._options = None
_ENDPOINT_HEALTHCHECKCONFIG.fields_by_name['port_value']._options = None
_LBENDPOINT.fields_by_name['load_balancing_weight']._options = None
_LOCALITYLBENDPOINTS.fields_by_name['load_balancing_weight']._options = None
_LOCALITYLBENDPOINTS.fields_by_name['priority']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v4alpha/substitution_format_string.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v4alpha/substitution_format_string.proto',
  package='envoy.config.core.v4alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.core.v4alphaB\035SubstitutionFormatStringProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:envoy/config/core/v4alpha/substitution_format_string.proto\x12\x19\x65nvoy.config.core.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe7\x02\n\x18SubstitutionFormatString\x12\x38\n\x0bjson_format\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x43\n\x12text_format_source\x18\x05 \x01(\x0b\x32%.envoy.config.core.v4alpha.DataSourceH\x00\x12\x19\n\x11omit_empty_values\x18\x03 \x01(\x08\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\x43\n\nformatters\x18\x06 \x03(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig:4\x9a\xc5\x88\x1e/\n-envoy.config.core.v3.SubstitutionFormatStringB\r\n\x06\x66ormat\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02R\x0btext_formatBR\n\'io.envoyproxy.envoy.config.core.v4alphaB\x1dSubstitutionFormatStringProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SUBSTITUTIONFORMATSTRING = _descriptor.Descriptor(
  name='SubstitutionFormatString',
  full_name='envoy.config.core.v4alpha.SubstitutionFormatString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_format', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.json_format', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_format_source', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.text_format_source', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='omit_empty_values', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.omit_empty_values', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.content_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatters', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.formatters', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.config.core.v3.SubstitutionFormatString',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='format', full_name='envoy.config.core.v4alpha.SubstitutionFormatString.format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=292,
  serialized_end=651,
)

_SUBSTITUTIONFORMATSTRING.fields_by_name['json_format'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_SUBSTITUTIONFORMATSTRING.fields_by_name['text_format_source'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._DATASOURCE
_SUBSTITUTIONFORMATSTRING.fields_by_name['formatters'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_SUBSTITUTIONFORMATSTRING.oneofs_by_name['format'].fields.append(
  _SUBSTITUTIONFORMATSTRING.fields_by_name['json_format'])
_SUBSTITUTIONFORMATSTRING.fields_by_name['json_format'].containing_oneof = _SUBSTITUTIONFORMATSTRING.oneofs_by_name['format']
_SUBSTITUTIONFORMATSTRING.oneofs_by_name['format'].fields.append(
  _SUBSTITUTIONFORMATSTRING.fields_by_name['text_format_source'])
_SUBSTITUTIONFORMATSTRING.fields_by_name['text_format_source'].containing_oneof = _SUBSTITUTIONFORMATSTRING.oneofs_by_name['format']
DESCRIPTOR.message_types_by_name['SubstitutionFormatString'] = _SUBSTITUTIONFORMATSTRING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubstitutionFormatString = _reflection.GeneratedProtocolMessageType('SubstitutionFormatString', (_message.Message,), {
  'DESCRIPTOR' : _SUBSTITUTIONFORMATSTRING,
  '__module__' : 'envoy.config.core.v4alpha.substitution_format_string_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v4alpha.SubstitutionFormatString)
  })
_sym_db.RegisterMessage(SubstitutionFormatString)


DESCRIPTOR._options = None
_SUBSTITUTIONFORMATSTRING.oneofs_by_name['format']._options = None
_SUBSTITUTIONFORMATSTRING.fields_by_name['json_format']._options = None
_SUBSTITUTIONFORMATSTRING._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/accesslog/v3/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.data.accesslog.v3 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/accesslog/v3/als.proto',
  package='envoy.service.accesslog.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.accesslog.v3B\010AlsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/service/accesslog/v3/als.proto\x12\x1a\x65nvoy.service.accesslog.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\'envoy/data/accesslog/v3/accesslog.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"V\n\x18StreamAccessLogsResponse::\x9a\xc5\x88\x1e\x35\n3envoy.service.accesslog.v2.StreamAccessLogsResponse\"\xff\x06\n\x17StreamAccessLogsMessage\x12R\n\nidentifier\x18\x01 \x01(\x0b\x32>.envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier\x12]\n\thttp_logs\x18\x02 \x01(\x0b\x32H.envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntriesH\x00\x12[\n\x08tcp_logs\x18\x03 \x01(\x0b\x32G.envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntriesH\x00\x1a\xa1\x01\n\nIdentifier\x12\x32\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x08log_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01:D\x9a\xc5\x88\x1e?\n=envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier\x1a\xb0\x01\n\x14HTTPAccessLogEntries\x12H\n\tlog_entry\x18\x01 \x03(\x0b\x32+.envoy.data.accesslog.v3.HTTPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:N\x9a\xc5\x88\x1eI\nGenvoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntries\x1a\xad\x01\n\x13TCPAccessLogEntries\x12G\n\tlog_entry\x18\x01 \x03(\x0b\x32*.envoy.data.accesslog.v3.TCPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:M\x9a\xc5\x88\x1eH\nFenvoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntries:9\x9a\xc5\x88\x1e\x34\n2envoy.service.accesslog.v2.StreamAccessLogsMessageB\x12\n\x0blog_entries\x12\x03\xf8\x42\x01\x32\x96\x01\n\x10\x41\x63\x63\x65ssLogService\x12\x81\x01\n\x10StreamAccessLogs\x12\x33.envoy.service.accesslog.v3.StreamAccessLogsMessage\x1a\x34.envoy.service.accesslog.v3.StreamAccessLogsResponse\"\x00(\x01\x42\x41\n(io.envoyproxy.envoy.service.accesslog.v3B\x08\x41lsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STREAMACCESSLOGSRESPONSE = _descriptor.Descriptor(
  name='StreamAccessLogsResponse',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0365\n3envoy.service.accesslog.v2.StreamAccessLogsResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=319,
)


_STREAMACCESSLOGSMESSAGE_IDENTIFIER = _descriptor.Descriptor(
  name='Identifier',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_name', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier.log_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036?\n=envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=783,
)

_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES = _descriptor.Descriptor(
  name='HTTPAccessLogEntries',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries.log_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntries',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=786,
  serialized_end=962,
)

_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES = _descriptor.Descriptor(
  name='TCPAccessLogEntries',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries.log_entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036H\nFenvoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntries',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1138,
)

_STREAMACCESSLOGSMESSAGE = _descriptor.Descriptor(
  name='StreamAccessLogsMessage',
  full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_logs', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.http_logs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_logs', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.tcp_logs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STREAMACCESSLOGSMESSAGE_IDENTIFIER, _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES, _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0364\n2envoy.service.accesslog.v2.StreamAccessLogsMessage',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='log_entries', full_name='envoy.service.accesslog.v3.StreamAccessLogsMessage.log_entries',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=322,
  serialized_end=1217,
)

_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry'].message_type = envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2._HTTPACCESSLOGENTRY
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry'].message_type = envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2._TCPACCESSLOGENTRY
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.containing_type = _STREAMACCESSLOGSMESSAGE
_STREAMACCESSLOGSMESSAGE.fields_by_name['identifier'].message_type = _STREAMACCESSLOGSMESSAGE_IDENTIFIER
_STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'].message_type = _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES
_STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'].message_type = _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries'].fields.append(
  _STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'])
_STREAMACCESSLOGSMESSAGE.fields_by_name['http_logs'].containing_oneof = _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries'].fields.append(
  _STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'])
_STREAMACCESSLOGSMESSAGE.fields_by_name['tcp_logs'].containing_oneof = _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']
DESCRIPTOR.message_types_by_name['StreamAccessLogsResponse'] = _STREAMACCESSLOGSRESPONSE
DESCRIPTOR.message_types_by_name['StreamAccessLogsMessage'] = _STREAMACCESSLOGSMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamAccessLogsResponse = _reflection.GeneratedProtocolMessageType('StreamAccessLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMACCESSLOGSRESPONSE,
  '__module__' : 'envoy.service.accesslog.v3.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsResponse)
  })
_sym_db.RegisterMessage(StreamAccessLogsResponse)

StreamAccessLogsMessage = _reflection.GeneratedProtocolMessageType('StreamAccessLogsMessage', (_message.Message,), {

  'Identifier' : _reflection.GeneratedProtocolMessageType('Identifier', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_IDENTIFIER,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.Identifier)
    })
  ,

  'HTTPAccessLogEntries' : _reflection.GeneratedProtocolMessageType('HTTPAccessLogEntries', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.HTTPAccessLogEntries)
    })
  ,

  'TCPAccessLogEntries' : _reflection.GeneratedProtocolMessageType('TCPAccessLogEntries', (_message.Message,), {
    'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES,
    '__module__' : 'envoy.service.accesslog.v3.als_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage.TCPAccessLogEntries)
    })
  ,
  'DESCRIPTOR' : _STREAMACCESSLOGSMESSAGE,
  '__module__' : 'envoy.service.accesslog.v3.als_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.accesslog.v3.StreamAccessLogsMessage)
  })
_sym_db.RegisterMessage(StreamAccessLogsMessage)
_sym_db.RegisterMessage(StreamAccessLogsMessage.Identifier)
_sym_db.RegisterMessage(StreamAccessLogsMessage.HTTPAccessLogEntries)
_sym_db.RegisterMessage(StreamAccessLogsMessage.TCPAccessLogEntries)


DESCRIPTOR._options = None
_STREAMACCESSLOGSRESPONSE._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._options = None
_STREAMACCESSLOGSMESSAGE_IDENTIFIER._options = None
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES._options = None
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES._options = None
_STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._options = None
_STREAMACCESSLOGSMESSAGE._options = None

_ACCESSLOGSERVICE = _descriptor.ServiceDescriptor(
  name='AccessLogService',
  full_name='envoy.service.accesslog.v3.AccessLogService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1220,
  serialized_end=1370,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamAccessLogs',
    full_name='envoy.service.accesslog.v3.AccessLogService.StreamAccessLogs',
    index=0,
    containing_service=None,
    input_type=_STREAMACCESSLOGSMESSAGE,
    output_type=_STREAMACCESSLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCESSLOGSERVICE)

DESCRIPTOR.services_by_name['AccessLogService'] = _ACCESSLOGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v4alpha/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/network/thrift_proxy/v4alpha/route.proto',
  package='envoy.extensions.filters.network.thrift_proxy.v4alpha',
  syntax='proto3',
  serialized_options=b'\nCio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v4alphaB\nRouteProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/extensions/filters/network/thrift_proxy/v4alpha/route.proto\x12\x35\x65nvoy.extensions.filters.network.thrift_proxy.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbc\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12L\n\x06routes\x18\x02 \x03(\x0b\x32<.envoy.extensions.filters.network.thrift_proxy.v4alpha.Route:J\x9a\xc5\x88\x1e\x45\nCenvoy.extensions.filters.network.thrift_proxy.v3.RouteConfiguration\"\xff\x01\n\x05Route\x12Z\n\x05match\x18\x01 \x01(\x0b\x32\x41.envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12[\n\x05route\x18\x02 \x01(\x0b\x32\x42.envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.network.thrift_proxy.v3.Route\"\xe3\x01\n\nRouteMatch\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06invert\x18\x03 \x01(\x08\x12:\n\x07headers\x18\x04 \x03(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcher:B\x9a\xc5\x88\x1e=\n;envoy.extensions.filters.network.thrift_proxy.v3.RouteMatchB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\"\xab\x03\n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x63\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32\x46.envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedClusterH\x00\x12\'\n\x0e\x63luster_header\x18\x06 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00H\x00\x12;\n\x0emetadata_match\x18\x03 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata\x12:\n\x0brate_limits\x18\x04 \x03(\x0b\x32%.envoy.config.route.v4alpha.RateLimit\x12\x1a\n\x12strip_service_name\x18\x05 \x01(\x08:C\x9a\xc5\x88\x1e>\n<envoy.extensions.filters.network.thrift_proxy.v3.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xc0\x03\n\x0fWeightedCluster\x12p\n\x08\x63lusters\x18\x01 \x03(\x0b\x32T.envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xf1\x01\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x35\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12;\n\x0emetadata_match\x18\x03 \x01(\x0b\x32#.envoy.config.core.v4alpha.Metadata:U\x9a\xc5\x88\x1eP\nNenvoy.extensions.filters.network.thrift_proxy.v3.WeightedCluster.ClusterWeight:G\x9a\xc5\x88\x1e\x42\n@envoy.extensions.filters.network.thrift_proxy.v3.WeightedClusterB[\nCio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v4alphaB\nRouteProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ROUTECONFIGURATION = _descriptor.Descriptor(
  name='RouteConfiguration',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteConfiguration.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routes', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteConfiguration.routes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036E\nCenvoy.extensions.filters.network.thrift_proxy.v3.RouteConfiguration',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=525,
)


_ROUTE = _descriptor.Descriptor(
  name='Route',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.Route',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.Route.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.Route.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.network.thrift_proxy.v3.Route',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=783,
)


_ROUTEMATCH = _descriptor.Descriptor(
  name='RouteMatch',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method_name', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch.method_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch.service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='invert', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch.invert', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='headers', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch.headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036=\n;envoy.extensions.filters.network.thrift_proxy.v3.RouteMatch',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='match_specifier', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch.match_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=786,
  serialized_end=1013,
)


_ROUTEACTION = _descriptor.Descriptor(
  name='RouteAction',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weighted_clusters', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.weighted_clusters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_header', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.cluster_header', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.metadata_match', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate_limits', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.rate_limits', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strip_service_name', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.strip_service_name', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036>\n<envoy.extensions.filters.network.thrift_proxy.v3.RouteAction',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_specifier', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction.cluster_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1016,
  serialized_end=1443,
)


_WEIGHTEDCLUSTER_CLUSTERWEIGHT = _descriptor.Descriptor(
  name='ClusterWeight',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeight.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeight.weight', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_match', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeight.metadata_match', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036P\nNenvoy.extensions.filters.network.thrift_proxy.v3.WeightedCluster.ClusterWeight',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1580,
  serialized_end=1821,
)

_WEIGHTEDCLUSTER = _descriptor.Descriptor(
  name='WeightedCluster',
  full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.clusters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEIGHTEDCLUSTER_CLUSTERWEIGHT, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036B\n@envoy.extensions.filters.network.thrift_proxy.v3.WeightedCluster',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1446,
  serialized_end=1894,
)

_ROUTECONFIGURATION.fields_by_name['routes'].message_type = _ROUTE
_ROUTE.fields_by_name['match'].message_type = _ROUTEMATCH
_ROUTE.fields_by_name['route'].message_type = _ROUTEACTION
_ROUTEMATCH.fields_by_name['headers'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_ROUTEMATCH.oneofs_by_name['match_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['method_name'])
_ROUTEMATCH.fields_by_name['method_name'].containing_oneof = _ROUTEMATCH.oneofs_by_name['match_specifier']
_ROUTEMATCH.oneofs_by_name['match_specifier'].fields.append(
  _ROUTEMATCH.fields_by_name['service_name'])
_ROUTEMATCH.fields_by_name['service_name'].containing_oneof = _ROUTEMATCH.oneofs_by_name['match_specifier']
_ROUTEACTION.fields_by_name['weighted_clusters'].message_type = _WEIGHTEDCLUSTER
_ROUTEACTION.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_ROUTEACTION.fields_by_name['rate_limits'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._RATELIMIT
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['cluster'])
_ROUTEACTION.fields_by_name['cluster'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['weighted_clusters'])
_ROUTEACTION.fields_by_name['weighted_clusters'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_ROUTEACTION.oneofs_by_name['cluster_specifier'].fields.append(
  _ROUTEACTION.fields_by_name['cluster_header'])
_ROUTEACTION.fields_by_name['cluster_header'].containing_oneof = _ROUTEACTION.oneofs_by_name['cluster_specifier']
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['metadata_match'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._METADATA
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.containing_type = _WEIGHTEDCLUSTER
_WEIGHTEDCLUSTER.fields_by_name['clusters'].message_type = _WEIGHTEDCLUSTER_CLUSTERWEIGHT
DESCRIPTOR.message_types_by_name['RouteConfiguration'] = _ROUTECONFIGURATION
DESCRIPTOR.message_types_by_name['Route'] = _ROUTE
DESCRIPTOR.message_types_by_name['RouteMatch'] = _ROUTEMATCH
DESCRIPTOR.message_types_by_name['RouteAction'] = _ROUTEACTION
DESCRIPTOR.message_types_by_name['WeightedCluster'] = _WEIGHTEDCLUSTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RouteConfiguration = _reflection.GeneratedProtocolMessageType('RouteConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _ROUTECONFIGURATION,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteConfiguration)
  })
_sym_db.RegisterMessage(RouteConfiguration)

Route = _reflection.GeneratedProtocolMessageType('Route', (_message.Message,), {
  'DESCRIPTOR' : _ROUTE,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.Route)
  })
_sym_db.RegisterMessage(Route)

RouteMatch = _reflection.GeneratedProtocolMessageType('RouteMatch', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEMATCH,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteMatch)
  })
_sym_db.RegisterMessage(RouteMatch)

RouteAction = _reflection.GeneratedProtocolMessageType('RouteAction', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEACTION,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.RouteAction)
  })
_sym_db.RegisterMessage(RouteAction)

WeightedCluster = _reflection.GeneratedProtocolMessageType('WeightedCluster', (_message.Message,), {

  'ClusterWeight' : _reflection.GeneratedProtocolMessageType('ClusterWeight', (_message.Message,), {
    'DESCRIPTOR' : _WEIGHTEDCLUSTER_CLUSTERWEIGHT,
    '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster.ClusterWeight)
    })
  ,
  'DESCRIPTOR' : _WEIGHTEDCLUSTER,
  '__module__' : 'envoy.extensions.filters.network.thrift_proxy.v4alpha.route_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.network.thrift_proxy.v4alpha.WeightedCluster)
  })
_sym_db.RegisterMessage(WeightedCluster)
_sym_db.RegisterMessage(WeightedCluster.ClusterWeight)


DESCRIPTOR._options = None
_ROUTECONFIGURATION._options = None
_ROUTE.fields_by_name['match']._options = None
_ROUTE.fields_by_name['route']._options = None
_ROUTE._options = None
_ROUTEMATCH.oneofs_by_name['match_specifier']._options = None
_ROUTEMATCH._options = None
_ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
_ROUTEACTION.fields_by_name['cluster']._options = None
_ROUTEACTION.fields_by_name['cluster_header']._options = None
_ROUTEACTION._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
_WEIGHTEDCLUSTER_CLUSTERWEIGHT._options = None
_WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
_WEIGHTEDCLUSTER._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/resource_monitor/fixed_heap/v2alpha/fixed_heap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/resource_monitor/fixed_heap/v2alpha/fixed_heap.proto',
  package='envoy.config.resource_monitor.fixed_heap.v2alpha',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.config.resource_monitor.fixed_heap.v2alphaB\016FixedHeapProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/config/resource_monitor/fixed_heap/v2alpha/fixed_heap.proto\x12\x30\x65nvoy.config.resource_monitor.fixed_heap.v2alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"7\n\x0f\x46ixedHeapConfig\x12$\n\x13max_heap_size_bytes\x18\x01 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02 \x00\x42Z\n>io.envoyproxy.envoy.config.resource_monitor.fixed_heap.v2alphaB\x0e\x46ixedHeapProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FIXEDHEAPCONFIG = _descriptor.Descriptor(
  name='FixedHeapConfig',
  full_name='envoy.config.resource_monitor.fixed_heap.v2alpha.FixedHeapConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_heap_size_bytes', full_name='envoy.config.resource_monitor.fixed_heap.v2alpha.FixedHeapConfig.max_heap_size_bytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\0042\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=230,
)

DESCRIPTOR.message_types_by_name['FixedHeapConfig'] = _FIXEDHEAPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FixedHeapConfig = _reflection.GeneratedProtocolMessageType('FixedHeapConfig', (_message.Message,), {
  'DESCRIPTOR' : _FIXEDHEAPCONFIG,
  '__module__' : 'envoy.config.resource_monitor.fixed_heap.v2alpha.fixed_heap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.resource_monitor.fixed_heap.v2alpha.FixedHeapConfig)
  })
_sym_db.RegisterMessage(FixedHeapConfig)


DESCRIPTOR._options = None
_FIXEDHEAPCONFIG.fields_by_name['max_heap_size_bytes']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto',
  package='envoy.extensions.watchdog.profile_action.v3alpha',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.watchdog.profile_action.v3alphaB\022ProfileActionProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEenvoy/extensions/watchdog/profile_action/v3alpha/profile_action.proto\x12\x30\x65nvoy.extensions.watchdog.profile_action.v3alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x7f\n\x13ProfileActionConfig\x12\x33\n\x10profile_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1d\n\x0cprofile_path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0cmax_profiles\x18\x03 \x01(\x04\x42\x66\n>io.envoyproxy.envoy.extensions.watchdog.profile_action.v3alphaB\x12ProfileActionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PROFILEACTIONCONFIG = _descriptor.Descriptor(
  name='ProfileActionConfig',
  full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile_duration', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.profile_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_path', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.profile_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_profiles', full_name='envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig.max_profiles', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=338,
)

_PROFILEACTIONCONFIG.fields_by_name['profile_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ProfileActionConfig'] = _PROFILEACTIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProfileActionConfig = _reflection.GeneratedProtocolMessageType('ProfileActionConfig', (_message.Message,), {
  'DESCRIPTOR' : _PROFILEACTIONCONFIG,
  '__module__' : 'envoy.extensions.watchdog.profile_action.v3alpha.profile_action_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.watchdog.profile_action.v3alpha.ProfileActionConfig)
  })
_sym_db.RegisterMessage(ProfileActionConfig)


DESCRIPTOR._options = None
_PROFILEACTIONCONFIG.fields_by_name['profile_path']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/header_to_metadata/v4alpha/header_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v4alpha import regex_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/header_to_metadata/v4alpha/header_to_metadata.proto',
  package='envoy.extensions.filters.http.header_to_metadata.v4alpha',
  syntax='proto3',
  serialized_options=b'\nFio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v4alphaB\025HeaderToMetadataProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQenvoy/extensions/filters/http/header_to_metadata/v4alpha/header_to_metadata.proto\x12\x38\x65nvoy.extensions.filters.http.header_to_metadata.v4alpha\x1a&envoy/type/matcher/v4alpha/regex.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xae\t\n\x06\x43onfig\x12\\\n\rrequest_rules\x18\x01 \x03(\x0b\x32\x45.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule\x12]\n\x0eresponse_rules\x18\x02 \x03(\x0b\x32\x45.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule\x1a\xc5\x03\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x05value\x18\x03 \x01(\tH\x00\x12R\n\x13regex_value_rewrite\x18\x06 \x01(\x0b\x32\x33.envoy.type.matcher.v4alpha.RegexMatchAndSubstituteH\x00\x12\x62\n\x04type\x18\x04 \x01(\x0e\x32J.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\\\n\x06\x65ncode\x18\x05 \x01(\x0e\x32L.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.ValueEncode:N\x9a\xc5\x88\x1eI\nGenvoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePairB\x0c\n\nvalue_type\x1a\xfd\x02\n\x04Rule\x12\x1d\n\x06header\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00H\x00\x12\x1d\n\x06\x63ookie\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00H\x00\x12\x61\n\non_present\x18\x02 \x01(\x0b\x32M.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair\x12\x61\n\non_missing\x18\x03 \x01(\x0b\x32M.envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair\x12\x0e\n\x06remove\x18\x04 \x01(\x08:F\x9a\xc5\x88\x1e\x41\n?envoy.extensions.filters.http.header_to_metadata.v3.Config.RuleB\x19\n\x17header_cookie_specifier\"7\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x12\x12\n\x0ePROTOBUF_VALUE\x10\x02\"#\n\x0bValueEncode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x42\x41SE64\x10\x01:A\x9a\xc5\x88\x1e<\n:envoy.extensions.filters.http.header_to_metadata.v3.ConfigBi\nFio.envoyproxy.envoy.extensions.filters.http.header_to_metadata.v4alphaB\x15HeaderToMetadataProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_CONFIG_VALUETYPE = _descriptor.EnumDescriptor(
  name='ValueType',
  full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.ValueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTOBUF_VALUE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1314,
  serialized_end=1369,
)
_sym_db.RegisterEnumDescriptor(_CONFIG_VALUETYPE)

_CONFIG_VALUEENCODE = _descriptor.EnumDescriptor(
  name='ValueEncode',
  full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.ValueEncode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BASE64', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1371,
  serialized_end=1406,
)
_sym_db.RegisterEnumDescriptor(_CONFIG_VALUEENCODE)


_CONFIG_KEYVALUEPAIR = _descriptor.Descriptor(
  name='KeyValuePair',
  full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata_namespace', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.metadata_namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex_value_rewrite', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.regex_value_rewrite', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.type', index=4,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.encode', index=5,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036I\nGenvoy.extensions.filters.http.header_to_metadata.v3.Config.KeyValuePair',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_type', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair.value_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=475,
  serialized_end=928,
)

_CONFIG_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.header', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.cookie', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_present', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.on_present', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_missing', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.on_missing', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.remove', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036A\n?envoy.extensions.filters.http.header_to_metadata.v3.Config.Rule',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='header_cookie_specifier', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule.header_cookie_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=931,
  serialized_end=1312,
)

_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_rules', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.request_rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_rules', full_name='envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.response_rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONFIG_KEYVALUEPAIR, _CONFIG_RULE, ],
  enum_types=[
    _CONFIG_VALUETYPE,
    _CONFIG_VALUEENCODE,
  ],
  serialized_options=b'\232\305\210\036<\n:envoy.extensions.filters.http.header_to_metadata.v3.Config',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=1473,
)

_CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_regex__pb2._REGEXMATCHANDSUBSTITUTE
_CONFIG_KEYVALUEPAIR.fields_by_name['type'].enum_type = _CONFIG_VALUETYPE
_CONFIG_KEYVALUEPAIR.fields_by_name['encode'].enum_type = _CONFIG_VALUEENCODE
_CONFIG_KEYVALUEPAIR.containing_type = _CONFIG
_CONFIG_KEYVALUEPAIR.oneofs_by_name['value_type'].fields.append(
  _CONFIG_KEYVALUEPAIR.fields_by_name['value'])
_CONFIG_KEYVALUEPAIR.fields_by_name['value'].containing_oneof = _CONFIG_KEYVALUEPAIR.oneofs_by_name['value_type']
_CONFIG_KEYVALUEPAIR.oneofs_by_name['value_type'].fields.append(
  _CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite'])
_CONFIG_KEYVALUEPAIR.fields_by_name['regex_value_rewrite'].containing_oneof = _CONFIG_KEYVALUEPAIR.oneofs_by_name['value_type']
_CONFIG_RULE.fields_by_name['on_present'].message_type = _CONFIG_KEYVALUEPAIR
_CONFIG_RULE.fields_by_name['on_missing'].message_type = _CONFIG_KEYVALUEPAIR
_CONFIG_RULE.containing_type = _CONFIG
_CONFIG_RULE.oneofs_by_name['header_cookie_specifier'].fields.append(
  _CONFIG_RULE.fields_by_name['header'])
_CONFIG_RULE.fields_by_name['header'].containing_oneof = _CONFIG_RULE.oneofs_by_name['header_cookie_specifier']
_CONFIG_RULE.oneofs_by_name['header_cookie_specifier'].fields.append(
  _CONFIG_RULE.fields_by_name['cookie'])
_CONFIG_RULE.fields_by_name['cookie'].containing_oneof = _CONFIG_RULE.oneofs_by_name['header_cookie_specifier']
_CONFIG.fields_by_name['request_rules'].message_type = _CONFIG_RULE
_CONFIG.fields_by_name['response_rules'].message_type = _CONFIG_RULE
_CONFIG_VALUETYPE.containing_type = _CONFIG
_CONFIG_VALUEENCODE.containing_type = _CONFIG
DESCRIPTOR.message_types_by_name['Config'] = _CONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {

  'KeyValuePair' : _reflection.GeneratedProtocolMessageType('KeyValuePair', (_message.Message,), {
    'DESCRIPTOR' : _CONFIG_KEYVALUEPAIR,
    '__module__' : 'envoy.extensions.filters.http.header_to_metadata.v4alpha.header_to_metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.KeyValuePair)
    })
  ,

  'Rule' : _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
    'DESCRIPTOR' : _CONFIG_RULE,
    '__module__' : 'envoy.extensions.filters.http.header_to_metadata.v4alpha.header_to_metadata_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.header_to_metadata.v4alpha.Config.Rule)
    })
  ,
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'envoy.extensions.filters.http.header_to_metadata.v4alpha.header_to_metadata_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.header_to_metadata.v4alpha.Config)
  })
_sym_db.RegisterMessage(Config)
_sym_db.RegisterMessage(Config.KeyValuePair)
_sym_db.RegisterMessage(Config.Rule)


DESCRIPTOR._options = None
_CONFIG_KEYVALUEPAIR.fields_by_name['key']._options = None
_CONFIG_KEYVALUEPAIR.fields_by_name['type']._options = None
_CONFIG_KEYVALUEPAIR._options = None
_CONFIG_RULE.fields_by_name['header']._options = None
_CONFIG_RULE.fields_by_name['cookie']._options = None
_CONFIG_RULE._options = None
_CONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v2/api_listener.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v2/api_listener.proto',
  package='envoy.config.listener.v2',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.listener.v2B\020ApiListenerProtoP\001\362\230\376\217\005\032\022\030envoy.config.listener.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+envoy/config/listener/v2/api_listener.proto\x12\x18\x65nvoy.config.listener.v2\x1a\x19google/protobuf/any.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"9\n\x0b\x41piListener\x12*\n\x0c\x61pi_listener\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyBd\n&io.envoyproxy.envoy.config.listener.v2B\x10\x41piListenerProtoP\x01\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.listener.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_APILISTENER = _descriptor.Descriptor(
  name='ApiListener',
  full_name='envoy.config.listener.v2.ApiListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='api_listener', full_name='envoy.config.listener.v2.ApiListener.api_listener', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=220,
)

_APILISTENER.fields_by_name['api_listener'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['ApiListener'] = _APILISTENER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ApiListener = _reflection.GeneratedProtocolMessageType('ApiListener', (_message.Message,), {
  'DESCRIPTOR' : _APILISTENER,
  '__module__' : 'envoy.config.listener.v2.api_listener_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v2.ApiListener)
  })
_sym_db.RegisterMessage(ApiListener)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/grpc_stats/v2alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_method_list_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/grpc_stats/v2alpha/config.proto',
  package='envoy.config.filter.http.grpc_stats.v2alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\013ConfigProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.grpc_stats.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8envoy/config/filter/http/grpc_stats/v2alpha/config.proto\x12+envoy.config.filter.http.grpc_stats.v2alpha\x1a(envoy/api/v2/core/grpc_method_list.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xd3\x01\n\x0c\x46ilterConfig\x12\x19\n\x11\x65mit_filter_state\x18\x01 \x01(\x08\x12N\n!individual_method_stats_allowlist\x18\x02 \x01(\x0b\x32!.envoy.api.v2.core.GrpcMethodListH\x00\x12;\n\x15stats_for_all_methods\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x1b\n\x19per_method_stat_specifier\"M\n\x0c\x46ilterObject\x12\x1d\n\x15request_message_count\x18\x01 \x01(\x04\x12\x1e\n\x16response_message_count\x18\x02 \x01(\x04\x42\x85\x01\n9io.envoyproxy.envoy.config.filter.http.grpc_stats.v2alphaB\x0b\x43onfigProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.grpc_stats.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_FILTERCONFIG = _descriptor.Descriptor(
  name='FilterConfig',
  full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emit_filter_state', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.emit_filter_state', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='individual_method_stats_allowlist', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.individual_method_stats_allowlist', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_for_all_methods', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.stats_for_all_methods', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='per_method_stat_specifier', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig.per_method_stat_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=243,
  serialized_end=454,
)


_FILTEROBJECT = _descriptor.Descriptor(
  name='FilterObject',
  full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_message_count', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject.request_message_count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_message_count', full_name='envoy.config.filter.http.grpc_stats.v2alpha.FilterObject.response_message_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=533,
)

_FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'].message_type = envoy_dot_api_dot_v2_dot_core_dot_grpc__method__list__pb2._GRPCMETHODLIST
_FILTERCONFIG.fields_by_name['stats_for_all_methods'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FILTERCONFIG.oneofs_by_name['per_method_stat_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'])
_FILTERCONFIG.fields_by_name['individual_method_stats_allowlist'].containing_oneof = _FILTERCONFIG.oneofs_by_name['per_method_stat_specifier']
_FILTERCONFIG.oneofs_by_name['per_method_stat_specifier'].fields.append(
  _FILTERCONFIG.fields_by_name['stats_for_all_methods'])
_FILTERCONFIG.fields_by_name['stats_for_all_methods'].containing_oneof = _FILTERCONFIG.oneofs_by_name['per_method_stat_specifier']
DESCRIPTOR.message_types_by_name['FilterConfig'] = _FILTERCONFIG
DESCRIPTOR.message_types_by_name['FilterObject'] = _FILTEROBJECT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FilterConfig = _reflection.GeneratedProtocolMessageType('FilterConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILTERCONFIG,
  '__module__' : 'envoy.config.filter.http.grpc_stats.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.grpc_stats.v2alpha.FilterConfig)
  })
_sym_db.RegisterMessage(FilterConfig)

FilterObject = _reflection.GeneratedProtocolMessageType('FilterObject', (_message.Message,), {
  'DESCRIPTOR' : _FILTEROBJECT,
  '__module__' : 'envoy.config.filter.http.grpc_stats.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.grpc_stats.v2alpha.FilterObject)
  })
_sym_db.RegisterMessage(FilterObject)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
